@@ -30,7 +30,8 @@
 #include <string.h>
 #include <glib.h>
 #include <gconf/gconf-client.h>
-#include <libgnomeui/gnome-client.h>
+
+#include <libpanel-util/panel-cleanup.h>
 
 #undef PANEL_GCONF_DEBUG
 
@@ -39,8 +40,11 @@ panel_gconf_get_client (void)
 {
 	static GConfClient *panel_gconf_client = NULL;
 
-	if (!panel_gconf_client)
+	if (!panel_gconf_client) {
 		panel_gconf_client = gconf_client_get_default ();
+		panel_cleanup_register (panel_cleanup_unref_and_nullify,
+					&panel_gconf_client);
+	}
 
 	return panel_gconf_client;
 }
@@ -128,15 +132,13 @@ panel_gconf_global_key (const char *key)
 }
 
 const char *
-panel_gconf_general_key (const char *profile,
-			 const char *key)
+panel_gconf_general_key (const char *key)
 {
-	return panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/general/%s", profile, key);
+	return panel_gconf_sprintf (PANEL_CONFIG_DIR "/general/%s", key);
 }
 
 const char *
 panel_gconf_full_key (PanelGConfKeyType  type,
-		      const char        *profile,
 		      const char        *id,
 		      const char        *key)
 {
@@ -157,8 +159,8 @@ panel_gconf_full_key (PanelGConfKeyType  type,
 		break;
 	}
 
-	return panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/%s/%s/%s",
-				    profile, subdir, id, key);
+	return panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/%s/%s",
+				    subdir, id, key);
 }
 
 const char *
@@ -248,10 +250,10 @@ panel_gconf_copy_dir (GConfClient  *client,
 					       gconf_entry_get_schema_name (entry),
 					       NULL);
 
-		if (!gconf_entry_get_is_default (entry))
+		if (!gconf_entry_get_is_default (entry) && entry->value)
 			gconf_client_set (client, key, entry->value, NULL);
 
-		gconf_entry_free (entry);
+		gconf_entry_unref (entry);
 	}
 	g_slist_free (list);
 
@@ -303,7 +305,7 @@ panel_gconf_associate_schemas_in_dir (GConfClient  *client,
 		gconf_engine_associate_schema (
 			client->engine, key, gconf_entry_get_key (entry), NULL);
 
-		gconf_entry_free (entry);
+		gconf_entry_unref (entry);
 	}
 
 	g_slist_free (list);
@@ -331,3 +333,19 @@ panel_gconf_associate_schemas_in_dir (GConfClient  *client,
 
 	g_slist_free (list);
 }
+
+gint
+panel_gconf_value_strcmp (gconstpointer a,
+			  gconstpointer b)
+{
+	const char *str_a;
+	const char *str_b;
+
+	if (a == b || !a || !b)
+		return 0;
+
+	str_a = gconf_value_get_string (a);
+	str_b = gconf_value_get_string (b);
+
+	return strcmp (str_a, str_b);
+}
